<?xml version="1.0" ?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!--
  Style sheet for converting cgmo-interop-cases.xml into a static HTML
  document
        
	April 1, 2002 (LH)
	  Modify to include processing of 'ol' (in add'n to 'ul').
        December 26, 2001 (LH)
          Initially created, from xmlp-issues-html.xsl

  $Id: qawg-issues-html.xsl,v 1.0 2002/01/02 10:53:18 lhender Exp $
-->

<xsl:strip-space elements="*"/>
<xsl:output
   method="html"
   encoding="iso-8859-1"
   omit-xml-declaration="yes"
   doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
   />

<xsl:template match="/">
  <html>
    <head>
      <title>QAWG Issues List</title>


      <style type="text/css">
         body {color: black; background: white;}
         .Closed { background-color: #888888; }
      </style>

    </head>
    <body>

<!--
    <a href="http://www.w3.org/">
    <img src="http://www.w3.org/Icons/WWW/w3c_home" alt="W3C" height="48"
    width="72" border="0"/></a>
-->


    <div id="Logo">
    <a href="http://www.w3.org/"><img alt="W3C" src="http://www.w3.org/Icons/WWW/w3c_home" /></a>
    <a href="http://www.w3.org/QA/"><img alt="QA" src="http://www.w3.org/QA/images/qa" width="130"
    height="48" /></a></div>

    <h1>QA WG Issues List</h1>


    <h3>Last update: <xsl:value-of select="issues/@update"/></h3>
    
<!-- LH todo: fix the ./#drafts reference in the following... -->

    <p>Issues regarding the documents produced by
    the QA Working Group should be reported to <a
    href="mailto:www-qa@w3.org">www-qa@w3.org</a> (<a
    href="http://lists.w3.org/Archives/Public/www-qa/">public
    archives</a>).</p>

    <p>Comments on this list should be sent to the
    <a href="mailto:xml-dist-app@w3.org">www-qa@w3.org</a>
    mailing
    list (<a
    href="http://lists.w3.org/Archives/Public/www-qa">Archives</a>).</p>

<!-- LH todo:  replace pgph ...

	<p>In this document, AMG means abstract model group, RPCTF
	means RPC task force, TBTF means transport binding task force
	and ETF means encoding task force.</p>

... w/ any desired acronym expansion for QAWG -->

    <ul>
      <li><a href="#summaryList">Summary list of outstanding issues</a></li>
      <li><a href="#detailList">Detailed list of issues</a></li>
      <li><a href="#legend">Legend for detailed list</a></li>
    </ul>
     
    <xsl:apply-templates mode="summary" />
    <xsl:apply-templates mode="detail" />

    <hr/>

	<xsl:apply-templates select="issues/maintainer" />

    </body>
  </html> 
</xsl:template>

<xsl:template match="issues" mode="summary">
  <h2><a name="summaryList"></a>Summary List of Outstanding Issues</h2>
  <table border='1'>
      <tr>
        <th><a href="#num">num</a></th>
        <th><a href="#Status">Status</a></th>
        <th><a href="#Spec">Spec</a></th>
        <th><a href="#Topic">Topic</a></th>
        <th><a href="#Class">Class</a></th>
        <th><a href="#Date">Date</a></th>
        <th><a href="#Title">Title</a></th>
      </tr>
    <xsl:apply-templates select="issue[child::status!='Closed']"
	mode="summary">
      <xsl:sort select="status='Postponed'" />
      <xsl:sort select="status='Unassigned'" />
      <xsl:sort select="status='Active'" />
      <!--LH: need to change following for QA family-->
      <xsl:sort select="locus='AM'" />
      <xsl:sort select="locus='Spec'" />
      <xsl:sort select="topic" />
      <xsl:sort select="priority" order="descending"/>
      <xsl:sort select="date" />
      <xsl:sort data-type="number" select="issue-num" />
    </xsl:apply-templates>
  </table>
</xsl:template>

<xsl:template match="issue" mode="summary">
      <tr>
        <td>
          <a href="#x{issue-num}">
            <xsl:value-of select="issue-num"/>
          </a>
        </td>
        <td><xsl:value-of select="status"/></td>
        <td><xsl:value-of select="locus"/></td>
        <td><xsl:value-of select="topic"/></td>
        <td><xsl:value-of select="priority"/></td>
        <td><xsl:value-of select="date"/></td>
        <td><xsl:value-of select="title"/></td>
      </tr>
</xsl:template>

<xsl:template match="issues" mode="detail">
   <h2><a name="detailList"></a>Detailed List of Issues</h2>
  <table border='1'>
      <tr>
        <th><a href="#num">num</a></th>
        <th><a href="#Spec">Spec</a></th>
        <th><a href="#Date">Date</a></th>
        <th><a href="#Topic">Topic</a></th>
        <th><a href="#Class">Class</a></th>
        <th><a href="#Status">Status</a></th>
        <th><a href="#Raised by">Raised By</a></th>
        <th><a href="#Owner">Owner</a></th>
      </tr>
    <xsl:apply-templates select="issue" mode="detail">
      <xsl:sort data-type="number" select="issue-num" />
    </xsl:apply-templates>
  </table>
  <h2><a name="legend">Table Legend</a></h2>
   <dl>
   <dt><a name="num">num</a></dt>
   <dd>Issue number</dd>
   <dt><a name="title">Title</a></dt>
   <dd>Short title/name of the issue</dd>
   <dt><a name="Spec">Spec</a></dt>
   <dd>Document referred to in issue (Intro = Framework: Introduction; 
ProcOps = Framework: Process&amp;Operational Guidelines;
SpecGuide = Framework: Specification Guidelines)</dd>
   <dt><a name="Description">Description</a></dt>
   <dd>Short description of issue, possibly including link to origin of issue</dd>
   <dt><a name="Date">Date</a></dt>
   <dd>The date at which the issue was raised or initially logged.</dd>
   <dt><a name="Topic">Topic</a></dt>
   <dd>Rough topic categorization, one of: ...tbd... [replace following XMLP stuff... env(elope), rpc, 
enc(oding), meta(issue), bind(ing), fault]</dd>
   <dt><a name="Class">Class</a></dt>
   <dd>Substantive or Editorial</dd>
   <dt><a name="Status">Status</a></dt>
   <dd>One of: Unassigned, Active, Closed, Postponed</dd>
   <dt><a name="Proposal">Proposal</a></dt>
   <dd>Current proposal for resolution of issue, possibly including link to further text</dd>
   <dt><a name="Resolution">Resolution</a></dt>
   <dd>Short description of resolution, possibly including link to a more elaborate description</dd>
   <dt><a name="Raised">Raised by</a></dt>
   <dd>Person who raised the issue</dd>
   <dt><a name="Owner">Owner</a></dt>
   <dd>QA WG Member responsible for the issue</dd>
   </dl>
</xsl:template>

<xsl:template match="issue" mode="detail">
                <tbody class="{status}">
      <tr>
        <xsl:apply-templates select="issue-num" mode="detail" />
        <xsl:apply-templates select="locus" mode="detail" />
        <xsl:apply-templates select="date" mode="detail" />
        <xsl:apply-templates select="topic" mode="detail" />
        <xsl:apply-templates select="priority" mode="detail" />
        <xsl:apply-templates select="status" mode="detail" />
        <xsl:apply-templates select="originator" mode="detail" />
        <xsl:apply-templates select="responsible" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="title" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="description" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="proposal" mode="detail" />
      </tr>
      <tr>
        <xsl:apply-templates select="resolution" mode="detail" />
      </tr>
                     </tbody>
</xsl:template>

<xsl:template match="issue-num" mode="detail">
  <td rowspan='5' valign='top'>
    <b><a name="x{.}"><xsl:value-of select="."/></a></b> 
  </td>
</xsl:template>

<xsl:template match="locus" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="date" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="topic" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="priority" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="status" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="originator" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="responsible" mode="detail">
  <td>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="title" mode="detail">
  <td colspan='7'>
    <b>Title:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="description" mode="detail">
  <td colspan='7'>
    <b>Description:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="proposal" mode="detail">
  <td colspan='7'>
    <b>Proposal:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<xsl:template match="resolution" mode="detail">
  <td colspan='7'>
    <b>Resolution:</b>
    <xsl:text> </xsl:text>
    <xsl:apply-templates />
  </td>
</xsl:template>

<!-- Sign the document -->

  <xsl:template match="maintainer">
    <address>
      <small>
	Maintained by <a href="{uri}"><xsl:value-of select="fullname"/>.</a>
      </small>
    </address>
  </xsl:template>

<!-- HTML like stuff -->

<xsl:template match="a[@href]">
    <a>
      <xsl:attribute name="href">
        <xsl:value-of select="@href"/>
      </xsl:attribute>
      <xsl:apply-templates />
    </a>
</xsl:template>

<xsl:template match="a[@name]">
    <a>
      <xsl:attribute name="name">
        <xsl:value-of select="@name"/>
      </xsl:attribute>
      <xsl:apply-templates />
    </a>
</xsl:template>

<xsl:template match="pre">
  <pre>
    <xsl:apply-templates />
  </pre>
</xsl:template>

<xsl:template match="p">
  <p>
    <xsl:apply-templates />
  </p>
</xsl:template>

<xsl:template match="em">
  <em>
    <xsl:apply-templates />
  </em>
</xsl:template>

<xsl:template match="ul">
  <ul>
    <xsl:for-each select="li">
      <li><xsl:apply-templates /></li>
    </xsl:for-each>
  </ul>
</xsl:template>
<xsl:template match="ol">
  <ol>
    <xsl:for-each select="li">
      <li><xsl:apply-templates /></li>
    </xsl:for-each>
  </ol>
</xsl:template>

</xsl:stylesheet>
